from _typeshed import Incomplete
from collections import UserDict

ALIASES: Incomplete

class Aliases(UserDict):
    @classmethod
    def default(cls): ...
    @staticmethod
    def compile(alias): ...
    def process_aliases(self, cmd: str): ...
    regexes: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def __setitem__(self, alias, replacement) -> None: ...
    def __delitem__(self, alias) -> None: ...
